{% load i18n %}

<!-- own srp requests -->
<div class="card">
    <div class="card-body">
        <div class="alert alert-info" role="alert">
            <div class="text-end srp-dashboard-user-isk-cost">
                {% translate "My total SRP cost" %}:
                <span id="srp-dashboard-user-isk-cost-amount" data-total-srp-cost="{{ total_srp_cost }}"></span>
            </div>
        </div>

        {% include "aasrp/partials/view-own-requests/datatables-filter.html" %}

        <div class="table-responsive">
            <table class="table table-striped table-aasrp table-srp-requests w-100" id="table_tab-user-srp-requests">
                <thead>
                    <tr>
                        <th class="w-auto">{% translate "Request time" %}</th>
                        <th class="w-auto">{% translate "Character" %}</th>
                        <th class="w-auto">{% translate "Request details" %}</th>
                        <th class="w-auto">{% translate "Ship" %}</th>
                        <th class="w-auto">{% translate "ISK lost" %}</th>
                        <th class="w-auto">{% translate "SRP payout" %}</th>
                        <th class="w-auto"><!-- {% translate "Status" %} --></th>

                        {% comment %}
                        Hidden columns for data that is needed for the datatable but
                        not relevant to show to the user in a column of its own.
                        {% endcomment %}
                        <th class="w-auto"><!-- {% translate "SRP code" %} --></th>
                        <th class="w-auto"><!-- {% translate "Request code" %} --></th>
                        <th class="w-auto"><!-- {% translate "Request status" %} --></th>
                        <th class="w-auto"><!-- {% translate "Killboard link" %} --></th>
                    </tr>
                </thead>

                <tbody></tbody>
            </table>
        </div>
    </div>
</div>
